# Sorpus
![CI/CD: Workflow](https://img.shields.io/badge/CI/CD-Workflow-green)
[![PyPI](https://img.shields.io/badge/PyPI-v.0.0.1_alpha-blue)](https://pypi.org/project/sorpus/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


Sentence (OpeRations) Processing UtilitieS.

Sorpus is a sentence processing library for computational linguistics and natural language processing. It is a demo version currently under development, where I am adding features that I personally felt were necessary but were not available in other libraries. 
## Install
```
! pip install sorpus
```
## Document
https://sites.google.com/view/sorpus/
